/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState } from 'react'
import styled from 'styled-components'
import Button from '@material-ui/core/Button';
import GroupIcon from '@material-ui/icons/Group';
import ModalConfirmarUnfollow from '../ModalConfirmarUnfollow.js'
import { putRequest } from '../HelperFunctions/getAxiosConfig'

export default function FollowingButton(props) {

    const [modalOpen, toggleModal] = useState(false)
    const [unfollowID, setUnfollowID] = useState(-1)

    const [followingHover, handleFollowingHover] = useState(false)
    const toggleFollowingHover = (value) => { handleFollowingHover(value) }

    const handleUnfollowPartOne = (followedID) => {
        setUnfollowID(followedID)
        toggleModal(true)
    }


    function handleSuccess(data) {
        props.toggleFollowed()
        toggleModal(false)
    }
    const handleUnfollowPartTwo = () => {
        const url = `/users/${unfollowID}/follow/`

        putRequest(url, {}, handleSuccess, (error) => { console.log(error) })
    }

    return (
        <React.Fragment>
            <ModalConfirmarUnfollow contrast={props.contrast} open={modalOpen}
                handleClose={() => { toggleModal(false) }}
                handleConfirm={handleUnfollowPartTwo}
            />
            <StyledButton
                contrast={props.contrast}
                className={`${props.contrast}LinkColor`}
                onMouseOver={() => toggleFollowingHover(true)}
                onMouseLeave={() => toggleFollowingHover(false)}
                onClick={() => handleUnfollowPartOne(props.followedID)}
            >
                {
                    followingHover ?
                        (
                            [
                                <div className={`${props.contrast}LinkColor`}>
                                    DEIXAR DE SEGUIR
                                </div>
                            ]
                        )
                        : (
                            [
                                <div className={`${props.contrast}LinkColor`}>
                                    <GroupIcon
                                        className={`${props.contrast}IconColor`}
                                        style={{
                                            fontSize: "24px",
                                            display: "inline-block",
                                            verticalAlign: "middle",
                                        }} 
                                    />
                                    SEGUINDO
                                </div>
                            ]
                        )
                }
            </StyledButton>
        </React.Fragment>
    )
}

export function NoIconFollowing(props) {
    const [modalOpen, toggleModal] = useState(false)
    const [unfollowID, setUnfollowID] = useState(-1)

    const [followingHover, handleFollowingHover] = useState(false)
    const toggleFollowingHover = (value) => { handleFollowingHover(value) }

    const handleUnfollowPartOne = (followedID) => {
        setUnfollowID(followedID)
        toggleModal(true)
    }


    function handleSuccess(data) {
        props.toggleFollowed()
        toggleModal(false)
    }
    const handleUnfollowPartTwo = () => {
        const url = `/users/${unfollowID}/follow/`

        putRequest(url, {}, handleSuccess, (error) => { console.log(error) })
    }

    return (
        <React.Fragment>
            <ModalConfirmarUnfollow contrast={props.contrast} open={modalOpen}
                handleClose={() => { toggleModal(false) }}
                handleConfirm={handleUnfollowPartTwo}
            />
            <NoIconButton
                contrast={props.contrast}
                onMouseOver={() => toggleFollowingHover(true)}
                onMouseLeave={() => toggleFollowingHover(false)}
                onClick={() => handleUnfollowPartOne(props.followedID)}
            >
                {
                    followingHover ?
                        (
                            [
                                <span>DEIXAR DE SEGUIR</span>
                            ]
                        )
                        : (
                            [
                                <span>SEGUINDO</span>
                            ]
                        )
                }
            </NoIconButton>
        </React.Fragment>
    )
}


export const StyledButton = styled(Button)`
    border : 1px solid white !important; 
    background-color: ${props => props.contrast === "" ? "#00bcd4" : "black"} !important;
    color: white !important;   
    font-size : 14px important;
    font-weight : 500 !important;

    .MuiSvgIcon-root {
        font-size : 24px;
    }

`

const NoIconButton = styled(Button)`
    &:hover {
        background-color: ${props => props.contrast === "" ? "" : "rgba(255,255,0,0.24) !important"};
    }
    .MuiButton-label {
        color: ${props => props.contrast === "" ? "#00bcd4 !important" : "yellow !important"};
    }
    background-color: ${props => props.contrast === "" ? "#fff !important" : "black !important"};
    border: ${props => props.contrast === "" ? "solid 1px rgba(0,188,212,.85) !important" : "solid 1px white !important"};
    font-size : 14px !important;
    border-radius : 3px !important;
    height : 36px !important;
    min-width : 88px !important;
    vertical-align : middle !important;
    align-items : center !important;
    text-align : center !important;
    padding : 0 6px !important;
    margin : 6px 8px !important;

    span{
        text-decoration: ${props => props.contrast === "" ? "none !important" : "underline !important"};
    }
`
