/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useEffect } from 'react'
import LoadingSpinner from '../../LoadingSpinner.js'
import Template from '../PanelComponents/TemplateRecurso.js'
import { getRequest } from '../../HelperFunctions/getAxiosConfig'

export default function TabPanelAtividades({ id, username, contrast }) {
    const [loading, handleLoading] = useState(true)

    const [errorInLearnObj, setErrorInLearnObj] = useState(false)
    const [loadingMoreLearnObj, setLoadingMoreLearnObj] = useState(false)
    const [currLimitLearnObj, setCurrLimitLearnObj] = useState(4);
    const [endOfLearnObj, setEndofLearndObj] = useState(0);
    const [learningObjects, setLearningObjects] = useState([]);

    function handleSuccess(data, headers) {
        setErrorInLearnObj(data.errors ? true : false)
        setLearningObjects(data)
        if (headers.has('X-Total-Count')) {
            setEndofLearndObj(headers.get('X-Total-Count'));
        }
        handleLoading(false)
    }

    function handleError(error) {
        handleLoading(false)
        setErrorInLearnObj(true)
    }

    useEffect(() => {
        const url = `/users/${id}/learning_objects?offset=0&limit=4`;
        handleLoading(true);
        getRequest(url, handleSuccess, handleError);
    }, [])

    const showMoreLearnObj = (limite) => {
        setLoadingMoreLearnObj(true);
        const limit = limite;
        setCurrLimitLearnObj(currLimitLearnObj + limit)
        const url = `/users/${id}/learning_objects?offset=${currLimitLearnObj}&limit=${limit}`;
        getRequest(url,
            (data) => {
                if (data.errors) {
                    setLoadingMoreLearnObj(false);
                    setErrorInLearnObj(true)
                }
                else if (data.length >= 1) {
                    let currData = [...learningObjects];
                    currData = [...currData.concat(data)];
                    setLoadingMoreLearnObj(false);
                    setLearningObjects(currData);
                }
                else {
                    setLoadingMoreLearnObj(false);
                }
            },
            (error) => {
                setLoadingMoreLearnObj(false);
                setErrorInLearnObj(true)
            }
        )
    }

    return (
        <>
            {
                loading ?
                    (
                        <LoadingSpinner contrast={contrast} text={`Carregando os recursos de ${username}`} />
                    )
                    :
                    (
                        [
                            <React.Fragment>
                                <Template
                                    contrast={contrast}
                                    length={learningObjects.length}
                                    titleText={learningObjects.length === 1 ? `Recurso publicado de ${username}` : `Recursos publicados ${username}`}
                                    noContentText={`${username} ainda não publicou nenhum Recurso!`}
                                    slice={learningObjects}
                                    showMore={showMoreLearnObj}
                                    loadingMore={loadingMoreLearnObj}
                                    end={endOfLearnObj}
                                    error={errorInLearnObj}
                                />
                            </React.Fragment>
                        ]
                    )
            }
        </>
    )
}
