/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, memo } from 'react'
import FormControl from '@material-ui/core/FormControl';
import { StyledTextField, StyledFormLabel } from '../StyledComponents.js'
import { makeStyles } from "@material-ui/styles";

const useStyles = makeStyles(theme => ({
    darkTextField: {
        maxWidth: "100%",
        fontSize: "15px",
        fontWeight: "lighter",
        color: "white",
        width: "100%",
    },
    lightTextField: {
        maxWidth: "100%",
        fontSize: "15px",
        fontWeight: "lighter",
        color: "black",
        width: "100%",
    }
}));


function NewTitle(props) {
    const classes = useStyles();
    const [objTitle, setFormValue] = useState({
        error: false,
        value: props.initialValue ? props.initialValue : ""
    })
    const handleChangeTitle = (e) => {
        let userInput = e.target.value
        let flag = (userInput.length > 100 || userInput.length === 0 ? true : false)
        setFormValue({
            ...objTitle,
            error: flag,
            value: userInput
        })
    }

    return (
        <FormControl required={true} style={{ width: "100%", height: "100px" }}>
            <StyledFormLabel contrast={props.contrast} component="legend" style={{ fontSize: "14px", marginBottom: "10px" }}>
                <b>Título do Recurso</b>
            </StyledFormLabel>
            <StyledTextField
                contrast={props.contrast}
                id={"title-form"}
                placeholder="Ex: Jogo Virtual sobre os Biomas do Brasil"
                type={"text"}
                value={objTitle.value}
                variant="outlined"
                onChange={e => { handleChangeTitle(e) }}
                helperText={objTitle.value.length + "/100"}
                InputProps={props.contrast === "" ? { className: classes.lightTextField } : { className: classes.darkTextField }}
                error={objTitle.error}
                fullWidth
                multiline
                onBlur={() => { props.onBlurCallback("name", objTitle.value, props.draftID) }}
            />
        </FormControl>
    )
}

export default memo(NewTitle)
