/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useEffect, useRef } from 'react'
import Grid from '@material-ui/core/Grid';
import styled from 'styled-components'
import DragAndDropThumbnail from './PartTwoComponents/DragAndDropThumbnail'
import EducationalStage from './PartTwoComponents/EducationalStage'
import Licenca from './PartTwoComponents/Licenca'
import Checkbox from '@material-ui/core/Checkbox';
import FormControlLabel from '@material-ui/core/FormControlLabel';
import FormControl from '@material-ui/core/FormControl';
import { StyledFormLabel } from './StyledComponents.js'
import ButtonsDiv from './ButtonsDiv.js'
import SubjectsAndThemes from './PartTwoComponents/SubjectsAndThemes.js'
import { SendInfo } from './SendInfo.js'
import EditThumbnail from './PartTwoComponents/EditThumbnail.js'
import DisplayThumbnail from './PartTwoComponents/DisplayThumbnail.js'
import CustomCircularProgress from './PartTwoComponents/CustomCircularProgress';
import { getRequest, putRequest } from '../HelperFunctions/getAxiosConfig.js'
import SnackBar from '../../Components/SnackbarComponent';
import LoadingSpinner from '../../Components/LoadingSpinner'

import { yellow, blue } from "@material-ui/core/colors";
import { withStyles } from '@material-ui/core/styles';

const BlueCheckBox = withStyles({
    root: {
        color: blue[400],
        '&$checked': {
            color: blue[600],
        },
    },
    checked: {},
})((props) => <Checkbox color="default" {...props} />);

const ContrastCheckBox = withStyles({
    root: {
        color: yellow[400],
        '&$checked': {
            color: yellow[600],
        },
    },
    checked: {},
})((props) => <Checkbox color="default" {...props} />);

export function LoadingDiv(props) {
    return (
        <div style={props.contrast === "" ? { width: "100%", display: "flex", alignItems: "center", justifyContent: "center", color: "#666" } : { width: "100%", display: "flex", alignItems: "center", justifyContent: "center", color: "white" }}>
            <CustomCircularProgress contrast={props.contrast} /> CARREGANDO IMAGEM
        </div>
    )
}

export default function PartTwo(props) {
    const didMountRef = useRef(false);

    const [eduStages, setEduStages] = useState([])
    const [subjects, setSubjects] = useState([])
    const [themes, setThemes] = useState([])

    const [learningObject, setLearningObject] = useState({})

    const [loading, toggleLoading] = useState(true)

    const [snackInfo, setSnackInfo] = useState({
        open: false,
        text: '',
        severity: '',
        color: '',
    })

    function handleCloseSnackBar() {
        const info = {
            open: false,
            text: '',
            severity: '',
            color: '',
        }
        handleSnackInfo(info)
    }

    function handleSnackInfo(info) {
        setSnackInfo({
            ...info
        })
    }

    function handleSuccess(data) {
        setSubjects(data.filter(subject => subject.theme === false).sort((a, b) => a.name > b.name ? 1 : -1))
        setThemes(data.filter(subject => subject.theme === true).sort((a, b) => a.name > b.name ? 1 : -1))
    }

    function checkPartTwo(data) {
        return (
            data.educational_stages.length !== 0 &&
            data.subjects.length !== 0 &&
            data.license !== null &&
            termsCheckbox
        )
    }

    function handleSuccessGetFormData(data) {
        if (checkPartTwo(data)) {
            props.stepperControl(1)
        } else {
            const info = {
                open: true,
                text: 'Preencha todos os campos obrigatórios, inclusive o acordo de termos de uso e de propriedade intelectual!',
                severity: 'warning',
                color: '#FFC125',
            }
            handleSnackInfo(info)
        }
    }

    function handleSuccessfulGet(data) {
        setLearningObject(data)
    }

    useEffect(() => {
        getRequest(`/educational_stages/`, (data) => { setEduStages(data) }, (error) => { console.log(error) })

        getRequest(`/subjects/`, handleSuccess, (error) => { console.log(error) })

        const url = `/learning_objects/${props.draftID}`
        getRequest(url, handleSuccessfulGet, (error) => { console.log(error) })
    }, [])

    useEffect(() => {
        if (didMountRef.current) {
            console.log(learningObject);
            toggleLoading(false)
        }
        else {
            didMountRef.current = true;
        }
    }, [learningObject])


    /*------------------------Licenca------------------------*/

    const [termsCheckbox, setChecked] = useState(false)
    const toggleCheckbox = () => {
        setChecked(!termsCheckbox)
    }

    const [thumbnail, setThumbnail] = useState('')
    const [tempUrl, setTempUrl] = useState('')

    const acceptFile = (file) => {
        const objectURL = URL.createObjectURL(file)
        console.log(file)
        setTempUrl(objectURL)
        setThumbnailStage('editing')
    }

    const updateThumb = (newThumbnail) => {
        setThumbnail(newThumbnail)
        console.log(thumbnail)
    }

    const handleDeleteThumb = () => {
        setThumbnail('');
        setTempUrl('');
        setThumbnailStage('default');
    }

    const finalizeThumb = () => {
        setThumbnailStage('uploading')

        const url = `/learning_objects/${props.draftID}`

        let fdThumb = new FormData()
        fdThumb.set('learning_object[thumbnail]', thumbnail)

        putRequest(url, fdThumb, (data) => { setThumbnailStage('done') }, (error) => { console.log(error) })
    }

    const [thumbnailStage, setThumbnailStage] = useState('default')

    const chooseRenderStageThumbnail = (contrast) => {
        switch (thumbnailStage) {
            case 'uploading':
                return (<LoadingDiv contrast={contrast} />)
            case 'done':
                return (<DisplayThumbnail handleDelete={handleDeleteThumb} acceptFile={acceptFile} contrast={contrast} thumbnail={thumbnail} />)
            case 'editing':
                return (<EditThumbnail contrast={contrast} finalizeThumb={finalizeThumb} tempImgURL={tempUrl} updateThumb={updateThumb} />)
            default:
                return (<DragAndDropThumbnail contrast={contrast} acceptFile={acceptFile} />)

        }
    }

    const handleSubmit = (e) => {
        e.preventDefault();
        getRequest(`/learning_objects/${props.draftID}`,
            handleSuccessGetFormData,
            () => {
                const info = {
                    open: true,
                    text: 'Não foi possível verificar o status da publicação!',
                    severity: 'error',
                    color: 'red',
                }
                handleSnackInfo(info)
            }
        )
    }

    return (
        <React.Fragment>
            <SnackBar
                snackbarOpen={snackInfo.open}
                handleClose={handleCloseSnackBar}
                severity={snackInfo.severity}
                color={snackInfo.color}
                text={snackInfo.text}
            />
            {
                !loading ? (
                    <form style={{ width: "100%" }} onSubmit={handleSubmit}>
                        <Grid item xs={12} style={{ paddingBottom: "40px" }}>
                            {chooseRenderStageThumbnail(props.contrast)}
                        </Grid>

                        <Grid item xs={12} style={{ paddingBottom: "40px" }}>
                            <EducationalStage contrast={props.contrast} draftID={props.draftID} eduStages={eduStages} onBlurCallback={SendInfo}
                                initialValue={learningObject.educational_stages !== null ? learningObject.educational_stages.map((stage) => String(stage.id)) : null}
                            />
                        </Grid>

                        <SubjectsAndThemes contrast={props.contrast} draftID={props.draftID} subjects={subjects} themes={themes} onUploadPage={true} onBlurCallback={SendInfo}
                            initialValue={learningObject.subjects !== null ? learningObject.subjects.map(subject => String(subject.id)) : null}
                        />

                        <Grid item xs={12} style={{ paddingBottom: "40px" }}>
                            <Licenca contrast={props.contrast} draftID={props.draftID} onBlurCallback={SendInfo} initialValue={learningObject.license ? learningObject.license.id : null} />
                        </Grid>

                        <Grid item xs={12} style={{ paddingBottom: "40px" }}>
                            <StyledFormControl required contrast={props.contrast}>
                                <StyledFormLabel contrast={props.contrast} component="legend" style={{ fontSize: "14px", marginBottom: "10px" }} >
                                    <b>Confirme se você concorda com os <strong onClick={() => window.open("/termos/", "_blank")} style={props.contrast === "" ? { color: "#ff7f00" } : { color: "yellow", textDecoration: "underline", cursor: "pointer" }}>termos de uso e de propriedade intelectual</strong></b>
                                </StyledFormLabel>
                                <FormControlLabel label={<span className="label">Li e concordo com os termos de uso e de propriedade intelectual.</span>} control={props.contrast === "" ? <BlueCheckBox checked={termsCheckbox} onChange={toggleCheckbox} /> : <ContrastCheckBox checked={termsCheckbox} onChange={toggleCheckbox} />}
                                />
                            </StyledFormControl>
                        </Grid>

                        <Grid item xs={12}>
                            <ButtonsDiv contrast={props.contrast} draftID={props.draftID} stepperControl={props.stepperControl} onPartTwo={true} />
                        </Grid>

                        <Grid item xs={12} style={{ marginTop: "20px" }}>
                            <span style={props.contrast === "" ? { marginTop: "20px", fontWeight: "200", color: "#a5a5a5", paddingLeft: "10px" } : { marginTop: "20px", fontWeight: "200", color: "white", paddingLeft: "10px" }}>
                                * Campos obrigatórios
                            </span>
                        </Grid>
                    </form>
                )
                    :
                    (
                        <LoadingSpinner contrast={props.contrast} text={"CARREGANDO"} />
                    )
            }
        </React.Fragment>
    )
}

const StyledFormControl = styled(FormControl)`
    .MuiCheckbox-colorSecondary.Mui-checked {
        color : #00bcd4 !important;
    }

    .label {
        font-size : 14px !important;
        color: ${props => props.contrast === "" ? "#666" : "yellow"};
        text-decoration: ${props => props.contrast === "" ? "none" : "underline"};
        font-weight : 200 !important;
    }
`
