/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React from 'react'
import { StyledFormLabel } from '../StyledComponents.js'
import AddAPhotoIcon from '@material-ui/icons/AddAPhoto';
import Grid from '@material-ui/core/Grid';
import styled from 'styled-components'

export default function DisplayThumbnail(props) {
    let windowWidth = window.innerWidth

    const handleUpload = (e, selectorFiles) => {
        e.preventDefault();
        props.acceptFile(selectorFiles[0])
    }

    return (
        <React.Fragment>
            <StyledFormLabel contrast={props.contrast} component="legend" style={{ fontSize: "14px", marginBottom: "10px" }}>
                {
                    props.onEditPage ?
                        (
                            <b style={{ fontWeight: "ligther" }}>Imagem ilustrativa do recurso</b>
                        )
                        :
                        (
                            <>
                                <b>Editando Imagem</b>
                                <span style={props.contrast === "" ? { color: "#a5a5a5" } : { color: "white" }}>(Deixe seu recurso completo, para que todos o entendam melhor.)</span>
                            </>
                        )
                }
            </StyledFormLabel>
            <ImagemCarregada container contrast={props.contrast}>
                <Grid item xs={windowWidth > 990 ? 6 : 12}>
                    <div className="img-preview">
                        <img alt="" src={props.thumbnail} />
                        <div className="alterar-imagem">
                            <input type="file" onChange={(e) => handleUpload(e, e.target.files)} id="upload-file-thumbnail" style={{ display: "none" }}
                            />
                            <label htmlFor="upload-file-thumbnail" style={{ height: "100%", width: "inherit", cursor: "pointer" }}>
                                <div className="interacoes">
                                    SUBSTITUIR <AddAPhotoIcon />
                                </div>
                            </label>
                            <div className="interacoes" onClick={() => { props.handleDelete() }}>
                                DELETAR <AddAPhotoIcon />
                            </div>
                        </div>
                    </div>
                </Grid>
                <Grid item xs={windowWidth > 990 ? 6 : 12}>
                    <div className="aviso-imagem-carregada">
                        Sua imagem foi enviada, porém pode ser que demore alguns minutos até nosso servidor atualiza-la na página do recurso.
                    </div>
                </Grid>
            </ImagemCarregada>
        </React.Fragment>
    )
}

const ImagemCarregada = styled(Grid)`
        .aviso-imagem-carregada {
            color: ${props => props.contrast === "" ? "#a5a5a5" : "white"};
            font-size : 12px;
            font-weight : 500;
            text-align : justify;
            float : right;
            margin-right : 20px;

            @media screen and (min-width : 990px) {
                padding-top : 20px;
                padding-left : 10px;
            }
        }

        .img-preview {
            display : block;
            max-height : 500px;
            overflow : hidden;
            border-radius : 10px;
            position : relative;

            .alterar-imagem{
                position : absolute;
                bottom : 0;
                display : flex;
                flex-direction : row;
                width : 100%;
                justify-content : flex-end;
                background-color : rgba(0,0,0,.5);

                .interacoes {
                    cursor : pointer;
                    display : flex;
                    justify-content : flex-end;
                    align-items : flex-end;
                    height : 100%;
                    padding : 10px;
                    color: ${props => props.contrast === "" ? "#fff" : "yellow"};
                    text-decoration: ${props => props.contrast === "" ? "none" : "underline"};
                    font-size : 14px;
                    .MuiSvgIcon-root {
                        vertical-align : middle !important;
                        color: #fff;
                    }
                }
            }

            img {
                height : 100%;
                width : 100%;
                object-fit : cover;
                border-radius : 10px;
                border : 0;
            }
        }
`
